@@ -137,7 +137,7 @@ def handle_python(server, data, options, homunculus_config, recreate):
         os.system('virtualenv --no-site-packages %s' % virtualenv_dir)
 
         dependencies = data['features']['python'].get('dependencies', [])
-        dependencies = ['homunculus_instancetools==0.0.4']
+        dependencies.append('homunculus_instancetools==0.0.4')
 
         # install dependencies
         for dependency in dependencies:
